# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from crc-pulp_file-client.models.file_file_publication_response import FileFilePublicationResponse

class TestFileFilePublicationResponse(unittest.TestCase):
    """FileFilePublicationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileFilePublicationResponse:
        """Test FileFilePublicationResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FileFilePublicationResponse`
        """
        model = FileFilePublicationResponse()
        if include_optional:
            return FileFilePublicationResponse(
                pulp_href = '',
                prn = '',
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                repository_version = '',
                repository = '',
                distributions = [
                    ''
                    ],
                manifest = 'PULP_MANIFEST',
                checkpoint = True
            )
        else:
            return FileFilePublicationResponse(
        )
        """

    def testFileFilePublicationResponse(self):
        """Test FileFilePublicationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from crc-pulp_file-client.models.async_operation_response import AsyncOperationResponse
from crc-pulp_file-client.models.content_summary_response import ContentSummaryResponse
from crc-pulp_file-client.models.file_file_alternate_content_source import FileFileAlternateContentSource
from crc-pulp_file-client.models.file_file_alternate_content_source_response import FileFileAlternateContentSourceResponse
from crc-pulp_file-client.models.file_file_content_response import FileFileContentResponse
from crc-pulp_file-client.models.file_file_distribution import FileFileDistribution
from crc-pulp_file-client.models.file_file_distribution_response import FileFileDistributionResponse
from crc-pulp_file-client.models.file_file_publication import FileFilePublication
from crc-pulp_file-client.models.file_file_publication_response import FileFilePublicationResponse
from crc-pulp_file-client.models.file_file_remote import FileFileRemote
from crc-pulp_file-client.models.file_file_remote_response import FileFileRemoteResponse
from crc-pulp_file-client.models.file_file_remote_response_hidden_fields_inner import FileFileRemoteResponseHiddenFieldsInner
from crc-pulp_file-client.models.file_file_repository import FileFileRepository
from crc-pulp_file-client.models.file_file_repository_response import FileFileRepositoryResponse
from crc-pulp_file-client.models.my_permissions_response import MyPermissionsResponse
from crc-pulp_file-client.models.nested_role import NestedRole
from crc-pulp_file-client.models.nested_role_response import NestedRoleResponse
from crc-pulp_file-client.models.object_roles_response import ObjectRolesResponse
from crc-pulp_file-client.models.paginated_repository_version_response_list import PaginatedRepositoryVersionResponseList
from crc-pulp_file-client.models.paginatedfile_file_alternate_content_source_response_list import PaginatedfileFileAlternateContentSourceResponseList
from crc-pulp_file-client.models.paginatedfile_file_content_response_list import PaginatedfileFileContentResponseList
from crc-pulp_file-client.models.paginatedfile_file_distribution_response_list import PaginatedfileFileDistributionResponseList
from crc-pulp_file-client.models.paginatedfile_file_publication_response_list import PaginatedfileFilePublicationResponseList
from crc-pulp_file-client.models.paginatedfile_file_remote_response_list import PaginatedfileFileRemoteResponseList
from crc-pulp_file-client.models.paginatedfile_file_repository_response_list import PaginatedfileFileRepositoryResponseList
from crc-pulp_file-client.models.patchedfile_file_alternate_content_source import PatchedfileFileAlternateContentSource
from crc-pulp_file-client.models.patchedfile_file_distribution import PatchedfileFileDistribution
from crc-pulp_file-client.models.patchedfile_file_remote import PatchedfileFileRemote
from crc-pulp_file-client.models.patchedfile_file_repository import PatchedfileFileRepository
from crc-pulp_file-client.models.policy_enum import PolicyEnum
from crc-pulp_file-client.models.repair import Repair
from crc-pulp_file-client.models.repository_add_remove_content import RepositoryAddRemoveContent
from crc-pulp_file-client.models.repository_sync_url import RepositorySyncURL
from crc-pulp_file-client.models.repository_version_response import RepositoryVersionResponse
from crc-pulp_file-client.models.set_label import SetLabel
from crc-pulp_file-client.models.set_label_response import SetLabelResponse
from crc-pulp_file-client.models.task_group_operation_response import TaskGroupOperationResponse
from crc-pulp_file-client.models.unset_label import UnsetLabel
from crc-pulp_file-client.models.unset_label_response import UnsetLabelResponse
